#
# spec file for package ghc-hedis
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global pkg_name hedis
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.10.2
Release:        2.1
Summary:        Client library for the Redis datastore: supports full command set, pipelining
License:        BSD-3-Clause
Group:          Development/Libraries/Haskell
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-HTTP-devel
BuildRequires:  ghc-async-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-bytestring-lexing-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-errors-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-network-devel
BuildRequires:  ghc-network-uri-devel
BuildRequires:  ghc-resource-pool-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-scanner-devel
BuildRequires:  ghc-stm-devel
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-tls-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
%if %{with tests}
BuildRequires:  ghc-HUnit-devel
BuildRequires:  ghc-doctest-devel
BuildRequires:  ghc-slave-thread-devel
BuildRequires:  ghc-test-framework-devel
BuildRequires:  ghc-test-framework-hunit-devel
%endif

%description
Redis is an open source, advanced key-value store. It is often referred to as a
data structure server since keys can contain strings, hashes, lists, sets and
sorted sets. This library is a Haskell client for the Redis datastore.
Compared to other Haskell client libraries it has some advantages:

[Compatibility with Latest Stable Redis:] Hedis is intended to be used with the
latest stable version of Redis (currently 3.2). Most redis commands
(<http://redis.io/commands>) are available as haskell functions, although
MONITOR and SYNC are intentionally omitted. Additionally, a low-level API is
exposed that makes it easy for the library user to implement further commands,
such as new commands from an experimental Redis version.

[Automatic Optimal Pipelining:] Commands are pipelined
(<http://redis.io/topics/pipelining>) as much as possible without any work by
the user. See <http://informatikr.com/2012/redis-pipelining.html> for a
technical explanation of automatic optimal pipelining.

[Enforced Pub/Sub semantics:] When subscribed to the Redis Pub/Sub server
(<http://redis.io/topics/pubsub>), clients are not allowed to issue commands
other than subscribing to or unsubscribing from channels. This library uses the
type system to enforce the correct behavior.

[Connect via TCP or Unix Domain Socket:] TCP sockets are the default way to
connect to a Redis server. For connections to a server on the same machine,
Unix domain sockets offer higher performance than the standard TCP connection.

For detailed documentation, see the "Database.Redis" module. .

%package devel
Summary:        Haskell %{pkg_name} library development files
Group:          Development/Libraries/Haskell
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG

%changelog
* Tue Jul 10 2018 psimons@suse.com
- Update hedis to version 0.10.2.
  [#] Changelog for Hedis
  [#]# 0.10.2
* Thu Apr 12 2018 psimons@suse.com
- Update hedis to version 0.10.1.
  A more detailed change log is not available.
* Wed Apr 19 2017 psimons@suse.com
- Update to version 0.9.8 with cabal2obs.
* Mon Jan 30 2017 psimons@suse.com
- Update to version 0.9.7 with cabal2obs.
* Fri Dec 16 2016 psimons@suse.com
- Update to version 0.9.5 with cabal2obs.
* Tue Oct 11 2016 psimons@suse.com
- Update to version 0.9.4 with cabal2obs.
* Thu Sep 15 2016 psimons@suse.com
- Update to version 0.9.3 revision 0 with cabal2obs.
* Sun Jul 10 2016 psimons@suse.com
- Update to version 0.6.10 revision 0 with cabal2obs.
